<?php

class EveryBoard_Framework_Helper {

	// Class members
	public $eb_default_framework = 'bootstrap3';
	public $eb_active_framework;
	public $eb_max_columns;

	/**
	 * Framework Helper constructor adds actions and sets class members.
	 * @param bool $add_scripts Add scripts action or not.
	 */
	public function __construct( $add_scripts ) {

		$options                   = get_option( 'render_framework' );
		$this->eb_active_framework = isset( $options['framework'] ) ? esc_attr( $options['framework'] ) : '';
		$this->eb_max_columns      = $this->get_max_cols();

		if ( $add_scripts ) {
			add_action( 'wp_enqueue_scripts', array( &$this, 'eb_framework_helper_enqueue_scripts' ) );
		}
	}

	/*
	 * Function to return "registered" frameworks.
	 * @return Array with frameworks.
	 */
	public function get_frameworks() {

		return array(
			'bootstrap3'  => 'Bootstrap 3',
			'bootstrap3_20col'  => 'Bootstrap 3 - 20 columns',
			'bootstrap'  => 'Bootstrap',
			'foundation' => 'Foundation',
			'percent'    => 'Percent',
			'suit'       => 'Suit Grid'
		);
	}

    /**
     * Function to return framework-specific wrap-classes for the boards grid system
     */
    public function board_wrapper_classes() {

        switch ( $this->eb_active_framework ) {
            case 'percent':
                $return_data    = '';
                break;
            case 'bootstrap3':
			case 'bootstrap3_20col':
                $return_data    = '';
                break;
            case 'bootstrap':
                $return_data    = '';
                break;
            case 'foundation':
                $return_data    = '';
                break;
            default:
                $return_data    = '';
                break;
        }
        return 'every_board'. $return_data;
    }

	/**
	 * Function to return html formatted for a row in the active framework.
	 * @param  string $css        Any extra classes to add to the row.
	 * @return string             Row HTML for the active framework.
	 */
	public function row_html( $css ) {

		switch ( $this->eb_active_framework ) {
			case 'percent':
				return '<div class="row rendered_row' . $css . '">';
			case 'bootstrap3':
			case 'bootstrap3_20col':
				return '<div class="row ' . $css . '">';
			case 'bootstrap':
				return '<div class="row-fluid ' . $css . '">';
			case 'foundation':
				return '<div class="row ' . $css . '">';
			case 'suit':
            	return '<div class="Grid Grid--fit ' . $css . '">';
			default:
				return '<div class="row rendered_row' . $css . '">';
		}
	}

	/**
	 * Function to return html formatted for a column in the active framework.
	 *
	 * @param array $current_col_size   The col sizes for the column about to be rendered
	 * @param string $css               Any extra classes to add to the col.
	 * @param array $page_col_size      The col sizes relative to the top board in case of nested boards
	 *
	 * @return string                   Framework-specific column HTML.
	 */
	public function col_html( $current_col_size, $css, $page_col_size=array() ) {

		$col_classes = $this->get_framework_col_classes($this->eb_active_framework, $current_col_size);

		if (!empty($page_col_size)) {
			$col_classes .= ' '. $this->get_page_col_classes($this->eb_active_framework, $page_col_size);
		}

		$col_classes .= (trim($css) !== '') ? $css: '';

		switch ( $this->eb_active_framework ) {
			case 'percent':
				return '<div class="rendered_col' . $css . '" style="width: ' . $current_col_size['smallscreen'] . '%; float: left;">';
			case 'bootstrap3':
			case 'bootstrap3_20col':
				return '<div class="'. $col_classes . '">';
			case 'bootstrap':
				return '<div class="'. $col_classes . '">';
			case 'foundation':
				return '<div class="'. $col_classes . '">';
			case 'suit':
				return '<div class="GridCell ' . $col_classes . '">';
			default:
				return '<div class="rendered_col' . $css . '" style="width: ' . $current_col_size['smallscreen'] . '%; float: left;">';
		}
	}

	/**
	 * Function to create framework-specific column-classes
	 * @param $active_framework
	 * @param $col_size
	 *
	 * @return string
	 */
	private function get_framework_col_classes($active_framework, $col_size) {
		switch ( $active_framework ) {
			case 'bootstrap3':
			case 'bootstrap3_20col':
				return "col-xs-${col_size['mobile']} col-sm-${col_size['tablet']} col-md-${col_size['smallscreen']} col-lg-${col_size['largescreen']}";
			case 'bootstrap':
				return "span${col_size['smallscreen']}";
			case 'foundation':
				return "columns large-${col_size['smallscreen']}";
			case 'suit':
				return "u-sm-size${col_size['mobile']}of12 u-md-size${col_size['tablet']}of12 u-lg-size${col_size['smallscreen']}of12";
			default:
				return "";
		}
	}

	/**
	 * Function to create framework-specific board column-classes
	 * @param $active_framework
	 * @param $col_size
	 *
	 * @return string
	 */
	private function get_page_col_classes($active_framework, $col_size) {
		switch ( $active_framework ) {
			case 'bootstrap3':
			case 'bootstrap3_20col':
				return "board-col-xs-${col_size['mobile']} board-col-sm-${col_size['tablet']} board-col-md-${col_size['smallscreen']} board-col-lg-${col_size['largescreen']}";
			case 'bootstrap':
				return "board-span${col_size['smallscreen']}";
			case 'foundation':
				return "board-large-${col_size['smallscreen']}";
			case 'suit':
                return ""; #"board-u-sm-size${col_size['mobile']}of12 board-u-md-size${col_size['tablet']}of12 board-u-lg-size${col_size['smallscreen']}of12";
			default:
				return "";
		}
	}

    /**
     * Sets framework specific classes for items based on their settings.
     *
     * @param $settings
     * @return string
     */
    public function get_item_css_classes( $settings ) {

        $classes = "";
        if( isset( $settings->devices ) ) {

            if( $settings->devices->mobile->hidden === 'true' ) {

                switch ( $this->eb_active_framework ) {
                    case 'bootstrap3':
					case 'bootstrap3_20col':
                        $classes .= 'hidden-xs ';
                        break;
					case 'suit':
						$classes .= 'u-sm-hidden ';
						break;
                }
            }

            if( $settings->devices->tablet->hidden === 'true' ) {

                switch ( $this->eb_active_framework ) {
                    case 'bootstrap3':
					case 'bootstrap3_20col':
                        $classes .= 'hidden-sm ';
                        break;
					case 'suit':
						$classes .= 'u-md-hidden ';
						break;
                }
            }

            if( $settings->devices->smallscreen->hidden === 'true' ) {

                switch ( $this->eb_active_framework ) {
                    case 'bootstrap3':
                        $classes .= 'hidden-md ';
                        break;
					case 'suit':
						$classes .= 'u-lg-hidden ';
						break;
                }
            }

            if( $settings->devices->largescreen->hidden === 'true' ) {

                switch ( $this->eb_active_framework ) {
                    case 'bootstrap3':
					case 'bootstrap3_20col':
                        $classes .= 'hidden-lg ';
                        break;
                }
            }
        }

        return $classes;
    }

	/**
	 * Function to enqueue scripts for the active framework.
	 */
    function eb_framework_helper_enqueue_scripts() {

        switch ( $this->eb_active_framework ) {
            case 'percent':
                break;
            case 'bootstrap':
                wp_enqueue_style( 'bootstrap-css', EVERYBOARD_BASE . 'assets/framework/bootstrap/css/bootstrap.min.css' );
                wp_enqueue_style( 'bootstrap-responsive-css', EVERYBOARD_BASE . 'assets/framework/bootstrap/css/bootstrap-responsive.min.css', array( 'bootstrap-css' ) );
                wp_enqueue_script( 'bootstrap-js', EVERYBOARD_BASE . 'assets/framework/bootstrap/js/bootstrap.min.js', array( 'jquery' ), "1.0", true );
                break;
			case 'bootstrap3_20col':
				break;
            case 'bootstrap3':
                wp_enqueue_style( 'bootstrap-css', EVERYBOARD_BASE . 'assets/framework/bootstrap3/css/bootstrap.min.css' );
                wp_enqueue_script( 'bootstrap-js', EVERYBOARD_BASE . 'assets/framework/bootstrap3/js/bootstrap.min.js', array( 'jquery' ) );
                break;
            case 'foundation':
                wp_enqueue_style( 'foundation-normalize-css', EVERYBOARD_BASE . 'assets/framework/foundation/css/normalize.css' );
                wp_enqueue_style( 'foundation-css', EVERYBOARD_BASE . 'assets/framework/foundation/css/foundation.min.css', array( 'foundation-normalize-css' ) );
                wp_enqueue_script( 'foundation-modernizr-js', EVERYBOARD_BASE . 'assets/framework/foundation/js/vendor/custom.modernizr.js' );
                wp_enqueue_script( 'foundation-js', EVERYBOARD_BASE . 'assets/framework/foundation/js/foundation.min.js', array( 'jquery' ) );
                break;
            default:
        }
    }

	/**
	 * Function to return max number of columns for the active framework.
	 * @return int Number of columns for active framework.
	 */
	public function get_max_cols() {

		switch ( $this->eb_active_framework ) {
			case 'bootstrap':
				return 12;
			case 'bootstrap3':
				return 12;
			case 'bootstrap3_20col':
				return 20;
			case 'percent':
				return 100;
			case 'foundation':
				return 12;
			case 'suit':
				return 12;
			default:
				return 100;
		}
	}

	/**
	 * Function to get content size classes
	 * @param $content_size
	 *
	 * @return string
	 */
	public function get_content_size_classes($content_size) {
		switch ( $this->eb_active_framework ) {
			case 'bootstrap3':
			case 'bootstrap3_20col':
				return "content-size-xs-${content_size['mobile']} content-size-sm-${content_size['tablet']} content-size-md-${content_size['smallscreen']} content-size-lg-${content_size['largescreen']}";
			case 'bootstrap':
				return "board-span${content_size['smallscreen']}";
			case 'foundation':
				return "board-large-${content_size['smallscreen']}";
			default:
				return "";
		}
	}
}